@@ -1,26 +1,26 @@
 ## Community matrix comm.matrix: n x m matrix with n=time step, m=species
-community.sync <- function (comm.matrix, nrands = 0, method=c("pearson", "kendall", "spearman"), 
+community.sync <- function (data, nrands = 0, method=c("pearson", "kendall", "spearman"), 
                             alternative=c("greater", "less"), type=1, quiet=FALSE, ...) {
   alternatives=c("greater", "less")
   alternative=match.arg(tolower(alternative), alternatives)
   
-  comm.matrix=as.matrix(comm.matrix)
+  data=as.matrix(data)
   results=list()
-  results$obs=community.sync.aux (comm.matrix)
-  results$meancorr=meancorr(comm.matrix, method=method, ...)$obs
+  results$obs=community.sync.aux(data)
+  results$meancorr=meancorr(data, method=method, ...)$obs
   
   if (nrands > 0) {
-    nr=NROW(comm.matrix)
-    nc=NCOL(comm.matrix)      
+    nr=NROW(data)
+    nc=NCOL(data)      
     if (!quiet)
       prog.bar=txtProgressBar(min = 0, max = nrands, style = 3)
     results$rands=numeric(length=nrands+1)*NA
     for (i in 1:nrands) {
       if (type==1)
-        rand.mat=apply(comm.matrix, 2, sample)
+        rand.mat=apply(data, 2, sample)
       else {
         lags=sample(1:nr, size=nc, replace=TRUE)
-        rand.mat=mlag(comm.matrix, lags)        
+        rand.mat=mlag(data, lags)        
       }
       results$rands[i]=community.sync.aux(rand.mat)
       if (!quiet)
@@ -37,8 +37,8 @@ community.sync <- function (comm.matrix, nrands = 0, method=c("pearson", "kendal
   return (results)
 }
 
-community.sync.aux <- function (comm.matrix) {
-  species.sd=apply(comm.matrix, MARGIN=2, FUN=sd)
-  community.var=var(rowSums(comm.matrix))
+community.sync.aux <- function (data) {
+  species.sd=apply(data, MARGIN=2, FUN=sd)
+  community.var=var(rowSums(data))
   return(community.var/sum(species.sd, na.rm=TRUE)^2)
 }
